@@ -204,7 +204,7 @@ $EXPECT_PROC -c "
 
 #hostsファイルのチェック
     expect {
-	-re \".*(Y.*\/ N:.*\).*\" {send Y\r}
+	-re \".*(Y.*\/ N.*\).*\" {send Y\r}
 	-re \".*OK.*\" {}
 	}
 
@@ -233,7 +233,7 @@ $EXPECT_PROC -c "
     send 9\r
     expect eof
 
-" >${AGENT_LOG}
+" >${AGENT_LOG} 2>&1
 
 echo install end
 
