@@ -11,15 +11,16 @@
 #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #GNU General Public License for more details
 
-#ユーザチェック
-if [ ! `whoami` = hinemos ]; then
-    echo "hinemosユーザで実行してください。"
-    exit 1
-fi
 
 #設定情報読み込み
 . /opt/hinemos/hinemos.cfg
 
+#ユーザチェック
+if [ ! `whoami` = ${HINEMOS_JBOSS_USER} ]; then
+	echo "${HINEMOS_JBOSS_USER} ユーザで実行してください。"
+	exit 1
+fi
+
 #
 #変数
 #
@@ -35,15 +36,15 @@ echo "###"
 echo "###              運用管理ソフトウェア Hinemos"
 echo "###            一括制御 セットアップスクリプト  Ver. ${VERSION}"
 echo "###"
-echo "###  Copyright (C) 2006 - 2009 NTT DATA Corporation."
+echo "###  Copyright (C) since 2006 NTT DATA Corporation."
 echo "###################################################################"
 
 
 
-#hinemosユーザの認証用の公開鍵の作成
+#JBoss起動ユーザの認証用の公開鍵の作成
 setup() {
     echo "" 
-    echo "hinemos ユーザの認証用の公開鍵をパスフレーズなしで作成します。"
+    echo "${HINEMOS_JBOSS_USER} ユーザの認証用の公開鍵をパスフレーズなしで作成します。"
     echo "よろしいですか? (Y/N default:Y)"
     while [ 1 ];
     do
@@ -95,11 +96,11 @@ setup() {
 }
 
 
-#監視対象ノードへのhinemosユーザの公開鍵の登録
+#監視対象ノードへのJBoss起動ユーザの公開鍵の登録
 entry() {
     if [ ! -e ${HOME}/.ssh/id_rsa.pub ]; then
         echo ""
-        echo "hinemosユーザの公開鍵が作成されていません。作成して下さい。"
+        echo "${HINEMOS_JBOSS_USER} ユーザの公開鍵が作成されていません。作成して下さい。"
         return
     fi
     
@@ -107,7 +108,7 @@ entry() {
 
     echo ""
     echo ""
-    echo "監視対象ノードのrootユーザのauthorized_keysファイルに、hinemosユーザの公開鍵を登録します。"
+    echo "監視対象ノードのrootユーザのauthorized_keysファイルに、${HINEMOS_JBOSS_USER} ユーザの公開鍵を登録します。"
 
     while [ 1 ];
     do
@@ -142,7 +143,7 @@ entry() {
 			;;
 		esac
 		
-		echo ${ROOT_HOME}".ssh/authorized_keysに、hinemosユーザの公開鍵を設定します。"
+		echo ${ROOT_HOME}".ssh/authorized_keysに、${HINEMOS_JBOSS_USER} ユーザの公開鍵を設定します。"
 		echo "よろしいですか? (Y/N default:Y)"
 		read ANS
 		ANS=${ANS:-Y}
@@ -181,7 +182,7 @@ do
     echo ""
     echo "一括制御機能のセットアップ"
     echo ""
-    echo "     1) hinemosユーザの認証用の公開鍵の作成"
+    echo "     1) ${HINEMOS_JBOSS_USER}ユーザの認証用の公開鍵の作成"
     echo "     2) 監視対象ノードへの公開鍵登録"
     echo "     9) 一括制御機能のセットアップ終了"
     echo ""
