@@ -8,9 +8,20 @@ echo "###    Script start at `date '+%Y-%m-%d %T'`    ###"
 echo "#################################################"
 echo ""
 
+function usage {
+        echo "usage: "
+        echo "$0 -v   : Get information about HINEMOS DB SUMMARY"
+        echo "$0 -vv  : Get information about HINEMOS DB SUMMARY + OS INFORMATION"
+        echo "$0 -vvv : Get information about DETAIL"
+        return 0
+}
+
+function init {
 ## Hinemos env
 . /opt/hinemos/hinemos.cfg
+}
 
+function hinemos {
 ## Version
 VER=`cat ${HINEMOS_HOME}/_version`
 VER_MJ=`echo ${VER} | cut -c1-3`
@@ -299,16 +310,159 @@ echo "NIC        : ${NIC}"
 echo "FileSystem : ${FS}"
 echo ""
 
+}
+
+function os {
+## cat /etc/redhat-release
+echo "### cat /etc/redhat-release ###"
+cat /etc/redhat-release
+echo -e "\n"
+
+## chkconfig --list | grep hinemos
+echo "###  chkconfig --list | grep hinemos ###"
+chkconfig --list | grep hinemos
+echo -e "\n"
+
+## rpm -qa
+echo "### rpm -qa ###"
+rpm -qa
+echo -e "\n"
+
 ## cpuinfo
-echo "### /prop/cpuinfo ###"
+echo "### /proc/cpuinfo ###"
 cat /proc/cpuinfo
+echo -e ""
 
 ## meminfo
 echo "### /proc/meminfo ###"
 cat /proc/meminfo
+echo -e "\n"
+
+## sar -P ALL
+echo "### sar -P ALL ###"
+sar -P ALL
+echo -e "\n"
+
+## sar -r
+echo "### sar -r ###"
+sar -r
+echo -e "\n"
+
+## sar -n DEV
+echo "### sar -n DEV ###"
+sar -n DEV
+echo -e "\n"
+
+## sar -n EDEV
+echo "### sar -n EDEV ###"
+sar -n EDEV
+echo -e "\n"
+
+## vmstat -n
+echo "### vmstat -n ###"
+vmstat -n
+echo -e "\n"
+
+## iostat -d -x
+echo "### iostat -d -x ###"
+iostat -d -x
+echo -e ""
+
+## ps -H auxwww
+echo "### ps -H auxwww ###"
+ps -H auxwww
+echo -e "\n"
+
+## netstat -s
+echo "### netstat -s ###"
+netstat -s
+echo -e "\n"
+
+## netstat -an
+echo "### netstat -an ###"
+netstat -an
+echo -e "\n"
+
+## df
+echo "### df ###"
+df
+echo -e "\n"
+
+## df -i
+echo "### df -i ###"
+df -i
+echo -e "\n"
+
+## uptime
+echo "### uptime ###"
+uptime
+echo -e "\n"
+
+## /proc/slabinfo
+echo "### /proc/slabinfo ###"
+cat /proc/slabinfo
+echo -e "\n"
+
+## /proc/vmstat
+echo "### /proc/vmstat ###"
+cat /proc/vmstat
+echo -e "\n"
+}
+
+function detail {
+## lsof
+echo "### lsof ###"
+lsof
+echo -e "\n"
+
+## twiddle.sh
+echo "### twiddle.sh ###"
+cd /tmp
+${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=PollerService,name=PollerManager" printPollerInfo
+${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=SharedTableService,name=SharedTable" printTableInfo
+echo -e "\n"
+
+## md5sum
+echo "### md5sum ###"
+cd ${HINEMOS_HOME}
+find `ls --ignore='var'` -type f | xargs md5sum
+cd -
+echo -e "\n"
+}
+
+
+if [ $# -eq 0 ]; then
+        usage
+        exit 1
+fi
+
+for OPTION in "$@"
+do
+        case $OPTION in
+                -v)
+                        init
+                        hinemos
+                        ;;
+                -vv)
+                        init
+                        hinemos
+                        os
+                        ;;
+                -vvv)
+                        init
+                        hinemos
+                        os
+                        detail
+                        ;;
+                *)
+                        usage
+                        exit 1
+        esac
+done
 
 echo ""
 echo "#################################################"
 echo "###     Script end at `date '+%Y-%m-%d %T'`     ###"
 echo "#################################################"
 
+exit 0
\ No newline at end of file
